% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/CST_PDFBest.R
\name{PDFBest}
\alias{PDFBest}
\title{Computing the Best Index PDFs combining two SFSs Index PDFs.}
\usage{
PDFBest(pdf_exp, bc_dataset1 = TRUE, bc_dataset2 = TRUE)
}
\arguments{
\item{pdf_exp}{Statistics array for the SFSs Index PDFs for a period of years
with dimensions (time, dataset = 2, statistic = 4, season).}

\item{bc_dataset1}{Logical (default = TRUE).
If TRUE the Index PDFs for the first SFS or dataset has been computed
with bias corrected.}

\item{bc_dataset2}{Logical (default = TRUE).
If TRUE the Index PDFs for the second SFS or dataset has been computed
with bias corrected.}
}
\value{
PDFBest() returns an array
with dimensions (time, statistic = 2, season).
The firt statistic is the parameter 'mean' of the PDF for the best estimation
combining the two SFSs PDFs.
The second statistic is the parameter 'standard deviation' of the PDF for
the best estimation combining the two SFSs PDFs.
}
\description{
This function implements the computation to obtain the index PDFs
(e.g. NAO index) obtained to combining the Index PDFs for two SFSs,
the Best Index estimation.
}
\examples{
# Example for the PDFBest function
pdf_exp <- c(1: (10 * 2 * 4 * 1))
dim(pdf_exp) <-  c(time = 10, dataset = 2, statistic = 4, season = 1)
res <- PDFBest(pdf_exp, bc_dataset1 = TRUE, bc_dataset2 = FALSE)
dim(res)
# time   statistic    season
#   10           2         1
str(res)
# num [1:10, 1:2, 1] 17.2 18.3 19.5 20.6 21.7 ...

}
\references{
Regionally improved seasonal forecast of precipitation through Best
estimation of winter NAO, Sanchez-Garcia, E. et al.,
Adv. Sci. Res., 16, 165174, 2019, https://doi.org/10.5194/asr-16-165-2019
}
\author{
Eroteida Sanchez-Garcia - AEMET, \email{esanchezg@aemet.es}
}
