% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/CST_PDFIndexHind.R
\name{PDFIndexHind}
\alias{PDFIndexHind}
\title{Computing the Index PDFs for a dataset of SFSs for a hindcats period.}
\usage{
PDFIndexHind(index_exp, index_obs, type_exp = "ens", method = "ME",
  na.rm = FALSE)
}
\arguments{
\item{index_exp}{Index (e.g. NAO index) array from SFSs
with dimensions (time, dataset, member, season) or 
(time, dataset, member=1, statistic=2, season). The dimensions 'time' must be 
greater than 2. When dimension 'statistic' doesn't exist, the dimension 
'member' must be greater than 1.}

\item{index_obs}{Index (e.g. NAO index) array from an observational database
or reanalysis with dimensions (time, dataset, member = 1, season). The 
dimension 'time' must be greater than 2.}

\item{type_exp}{A character string ('ens' or 'sta') to identify if the 
experiment output is an ensemble members or statistics.}

\item{method}{A character string indicating which methodology is applied
to compute the PDFs. One of "ME" (default) or "LMEV".}

\item{na.rm}{Logical (default = FALSE). Should missing values be removed?}
}
\value{
PDFIndexHind() returns an array
with dimensions (time, statistic = 4, dataset, season).
The firt statistic is the parameter 'mean' of the PDF with not bias corrected
The second statistic is the parameter 'standard deviation' of the PDF
with not bias corrected
The third statistic is the parameter 'mean' of the PDF with bias corrected
The fourth statistic is the parameter 'standard deviation' of the PDF
with bias corrected
}
\description{
This function implements the computation to obtain the index PDFs
(e.g. NAO index) to improve the index estimate from a dataset of SFSs
}
\examples{
# Example for the PDFIndexHind function
# Example 1 
index_obs <- 1 : (5 * 3 * 1 * 1) 
dim(index_obs) <- c(time = 5, dataset = 3, member = 1, season = 1)
index_exp <- 1 : (5 * 3 * 4 * 1)
dim(index_exp) <- c(time = 5, dataset = 3, member = 4, season = 1)
res <- PDFIndexHind(index_exp, index_obs)
str(res)
# num [1:5, 1:4, 1:3, 1] 23.5 24.5 25.5 26.5 27.5 22.5 22.5 22.5 22.5 22.5 ...
dim(res)
# time statistic   dataset   season
#   5         4         3        1
# Example 2
index_obs <- 1 : (5 * 3 * 1 * 1) 
dim(index_obs) <- c(time = 5, dataset = 3, member = 1, season = 1)
index_exp <- 1 : (5 * 3 * 1* 2 * 1)
dim(index_exp) <- c(time = 5, dataset = 3, member = 1, statistic = 2, season = 1)
res <- PDFIndexHind(index_exp, index_obs, type_exp = 'sta')
str(res)
# num [1:5, 1:4, 1:3, 1] 1 2 3 4 5 0 0 0 0 0 ...
dim(res)
# time statistic   dataset   season
#   5         4         3        1

}
\references{
Regionally improved seasonal forecast of precipitation through Best
estimation of winter NAO, Sanchez-Garcia, E. et al.,
Adv. Sci. Res., 16, 165174, 2019, https://doi.org/10.5194/asr-16-165-2019
}
\author{
Eroteida Sanchez-Garcia - AEMET, \email{esanchezg@aemet.es}
}
